@@ -92,7 +92,7 @@ pipeline *decompress_open (const char *filename)
 		char *name = xasprintf ("zcat < %s", filename);
 		cmd = pipecmd_new_function (name, &decompress_zlib, NULL,
 					    NULL);
-		sandbox_attach (sandbox, cmd);
+		pipecmd_pre_exec (cmd, sandbox_load, sandbox_free, sandbox);
 		free (name);
 		p = pipeline_new_commands (cmd, NULL);
 		goto got_pipeline;
@@ -109,7 +109,8 @@ pipeline *decompress_open (const char *filename)
 
 			cmd = pipecmd_new_argstr (comp->prog);
 			pipecmd_arg (cmd, filename);
-			sandbox_attach (sandbox, cmd);
+			pipecmd_pre_exec (cmd, sandbox_load, sandbox_free,
+					  sandbox);
 			p = pipeline_new_commands (cmd, NULL);
 			goto got_pipeline;
 		}
@@ -121,7 +122,7 @@ pipeline *decompress_open (const char *filename)
 	if (ext) {
 		cmd = pipecmd_new_argstr (GUNZIP " -S \"\"");
 		pipecmd_arg (cmd, filename);
-		sandbox_attach (sandbox, cmd);
+		pipecmd_pre_exec (cmd, sandbox_load, sandbox_free, sandbox);
 		p = pipeline_new_commands (cmd, NULL);
 		goto got_pipeline;
 	}
@@ -144,7 +145,7 @@ pipeline *decompress_fdopen (int fd)
 
 #ifdef HAVE_LIBZ
 	cmd = pipecmd_new_function ("zcat", &decompress_zlib, NULL, NULL);
-	sandbox_attach (sandbox, cmd);
+	pipecmd_pre_exec (cmd, sandbox_load, sandbox_free, sandbox);
 	p = pipeline_new_commands (cmd, NULL);
 #else /* HAVE_LIBZ */
 	p = pipeline_new ();
